@@ -6,12 +6,12 @@ pub struct EvalEnv<'r> {
     pub stack: Vec<Value>,
     pub bp: usize, // "Base Pointer" - used to access local variables.
     pub db: DB,
-    pub qy: &'r mut dyn Query,
+    pub qy: &'r mut dyn Transaction,
     pub call_depth: usize,
 }
 impl<'r> EvalEnv<'r> {
     /// Construct a new EvalEnv.
-    pub fn new(db: DB, qy: &'r mut dyn Query) -> Self {
+    pub fn new(db: DB, qy: &'r mut dyn Transaction) -> Self {
         EvalEnv {
             stack: Vec::new(),
             bp: 0,
@@ -489,6 +489,7 @@ impl<'r> EvalEnv<'r> {
             let sql = "EXEC sys.DropTable(".to_string() + &t.id.to_string() + ")";
             self.db.run(&sql, self.qy);
             self.db.tables.borrow_mut().remove(name);
+            self.db.function_reset.set(true);
             t.free_pages(&self.db);
         } else {
             panic!("Drop Table not found {}", name.str());
