@@ -1,13 +1,13 @@
 //!# Interface
 //!
 //!The method [Database]::run (or alternatively Database::run_timed) is called to execute an SQL query.
-//!This takes a [Query] parameter which accumulates SELECT results and which also has methods
+//!This takes a [Transaction] parameter which accumulates SELECT results and which also has methods
 //!for accessing the environment and controlling output. Custom builtin functions implement [CExp] and have access to the query
-//!via an [EvalEnv] parameter, which can be downcast if ncessary.   
+//!via an [EvalEnv] parameter, which can be downcast if necessary.   
 //!
 //!# Examples
 //! ```
-//!use rustdb::{Database, SharedPagedData, SimpleFileStorage, WebQuery, INITSQL};
+//!use rustdb::{Database, SharedPagedData, SimpleFileStorage, WebTransaction, INITSQL};
 //!use std::net::TcpListener;
 //!use std::sync::Arc;
 //!
@@ -21,7 +21,7 @@
 //!    let listener = TcpListener::bind("127.0.0.1:3000").unwrap();
 //!    for tcps in listener.incoming() {
 //!        if let Ok(mut tcps) = tcps {
-//!            if let Ok(mut wq) = WebQuery::new(&tcps) {
+//!            if let Ok(mut wq) = WebTransaction::new(&tcps) {
 //!                // wq.trace();
 //!                let sql = "EXEC web.Main()";
 //!                // Execute SQL. http response, SQL output, (status,headers,content) is accumulated in wq.
@@ -35,7 +35,8 @@
 //!    }
 //!```
 //!
-//![See here](https://github.com/georgebarwood/RustDB/blob/main/examples/axumtest.rs) for more advanced example (Axum webserver with ARGON hash function).
+//![See here](https://github.com/georgebarwood/RustDB/blob/main/examples/axumtest.rs) for more advanced example
+//! ( Axum webserver with ARGON hash function and query logging ).
 //!
 //!# Features
 //!
@@ -45,8 +46,8 @@
 //!
 //!# General Design of Database
 //!
-//!SortedFile stores fixed size Records in a tree of Pages.
-//!SortedFile is used to implement:
+//! SortedFile stores fixed size Records in a tree of Pages.
+//! SortedFile is used to implement:
 //!
 //! - Variable length values ( which are split into fragments - see bytes module - although up to 15 bytes can be stored directly. ).
 //!
@@ -54,11 +55,11 @@
 //!
 //! - Index storage ( an index record refers back to the main table ).
 //!
-//!Pages have a maximum size, and are stored in CompactFile, which stores logical pages in smaller regions of backing storage.
+//! When a page becomes too big, it is split into two pages.
 //!
-//!When a page becomes too big, it is split into two pages.
+//! Each page is implemented as a binary tree ( so there is a tree of trees ).
 //!
-//!Each page is implemented as a binary tree ( so there is a tree of trees ).
+//! [SharedPagedData] allows logical database pages to be shared to allow concurrent readers.
 //!
 //!# ToDo List
 //!
@@ -66,15 +67,7 @@
 //!
 //!Consider replication/backup/durability issues [Here](https://en.wikipedia.org/wiki/Durability_(database_systems))
 //!
-//! Have a replication server. Replication server has old copy of database, and log.
-//! Changes are sent to replication server, which adds changes to the log.
-//! At some point the old copy can be updated ( and the history is lost ).
-//! Replication server could be set to run 1 week behind.  
-//! Can set up extra replication servers from primary replication server.
-//! During cloning process, the replication server stops applying updates.
-//! Database at a paticular point in time can be recreated by running replication log forwards.
-//! Question is WHAT to sent to replication server?
-//! Seems logical to send update messages ( SQL strings and environment values ).
+//!Implement email in example program. Replication of log files. Server status.
 //!
 //!Sort out error handling for PARSEINT etc.
 //!
@@ -82,11 +75,11 @@
 //!
 
 pub use crate::{
-    genquery::{GenQuery, Part},
+    gentrans::{GenTransaction, Part},
     init::INITSQL,
     pstore::{AccessPagedData, SharedPagedData},
     stg::SimpleFileStorage,
-    web::WebQuery,
+    webtrans::WebTransaction,
 };
 
 #[cfg(feature = "builtin")]
@@ -117,7 +110,7 @@ use crate::{
     sortedfile::{Asc, Id, Record, SortedFile},
     stg::Storage,
     table::{ColInfo, IndexInfo, Row, SaveOp, Table, TablePtr},
-    util::{newmap, SmallSet},
+    util::{nd, newmap, SmallSet},
     value::*,
 };
 
@@ -140,11 +133,11 @@ mod util;
 
 // Modules that are always public.
 
-/// General Query.
-pub mod genquery;
+/// General Transaction ( implementation of Transaction ).
+pub mod gentrans;
 
-/// WebQuery struct with http support.
-pub mod web;
+/// WebTransaction ( alternative implementation of Transaction with http support ).
+pub mod webtrans;
 
 /// Initial SQL
 pub mod init;
@@ -282,7 +275,7 @@ pub struct Database {
 impl Database {
     /// Construct a new DB, based on the specified file.
     pub fn new(file: AccessPagedData, initsql: &str) -> DB {
-        let mut dq = DummyQuery {};
+        let mut dq = DummyTransaction {};
         let is_new = file.is_new();
         let mut tb = TableBuilder::new();
         let sys_schema = tb.nt("Schema", &[("Name", STRING)]);
@@ -389,7 +382,7 @@ GO
     }
 
     /// Run a batch of SQL.
-    pub fn run(self: &DB, source: &str, qy: &mut dyn Query) {
+    pub fn run(self: &DB, source: &str, qy: &mut dyn Transaction) {
         if let Some(e) = self.go(source, qy) {
             let err = format!(
                 "{} in {} at line {} column {}.",
@@ -401,7 +394,7 @@ GO
         }
     }
     /// Run a batch of SQL, printing the execution time.
-    pub fn run_timed(self: &DB, source: &str, qy: &mut dyn Query) {
+    pub fn run_timed(self: &DB, source: &str, qy: &mut dyn Transaction) {
         let start = std::time::Instant::now();
         self.run(source, qy);
         println!(
@@ -411,7 +404,7 @@ GO
         );
     }
     /// Run a batch of SQL.
-    pub fn go(self: &DB, source: &str, qy: &mut dyn Query) -> Option<SqlError> {
+    pub fn go(self: &DB, source: &str, qy: &mut dyn Transaction) -> Option<SqlError> {
         let mut p = Parser::new(source, self);
         let result = std::panic::catch_unwind(panic::AssertUnwindSafe(|| {
             p.batch(qy);
@@ -437,6 +430,7 @@ GO
     }
 
     /// Save updated tables to underlying file ( or rollback if there was an error ).
+    /// Returns the number of logical pages that were updated.
     pub fn save(self: &DB) -> usize {
         let op = if self.err.get() {
             self.err.set(false);
@@ -561,8 +555,8 @@ impl TableBuilder {
     }
 }
 
-/// Input/Output message. Query and response.
-pub trait Query: std::any::Any {
+/// Input/Output message. Query and Response.
+pub trait Transaction: std::any::Any {
     /// STATUSCODE builtin function. sets the response status code.
     fn status_code(&mut self, _code: i64) {}
 
@@ -589,7 +583,7 @@ pub trait Query: std::any::Any {
 
     /// Get file content.
     fn file_content(&mut self, _fnum: i64) -> Arc<Vec<u8>> {
-        Arc::new(Vec::new())
+        nd()
     }
 
     /// Set the error string.
@@ -602,8 +596,8 @@ pub trait Query: std::any::Any {
 }
 
 /// Query where output is printed to console (used for initialisation ).
-struct DummyQuery {}
-impl Query for DummyQuery {
+struct DummyTransaction {}
+impl Transaction for DummyTransaction {
     fn selected(&mut self, _values: &[Value]) {}
     /// Called if a panic ( error ) occurs.
     fn set_error(&mut self, err: String) {
